@@ -590,17 +590,17 @@ class SubmitHunyuanTo3DRapidJobRequest(AbstractModel):
         r"""
         :param _Prompt: 文生3D，3D内容的描述，中文正向提示词。
 最多支持200个 utf-8 字符。
-文生3D, image、image_url和 prompt必填其一，且prompt和image/image_url不能同时存在。
+文生3D, ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :type Prompt: str
         :param _ImageBase64: 输入图 Base64 数据。
-大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过6m）
+大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过5m）
 格式：jpg，png，jpeg，webp。
 ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :type ImageBase64: str
         :param _ImageUrl: 输入图Url。
-大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过6m）
+大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过5m）
 格式：jpg，png，jpeg，webp。
-ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
+ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :type ImageUrl: str
         :param _ResultFormat: 生成模型的格式，仅限制生成一种格式。
 生成模型文件组默认返回obj格式。
@@ -608,18 +608,21 @@ ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不
         :type ResultFormat: str
         :param _EnablePBR: 是否开启 PBR材质生成，默认 false。
         :type EnablePBR: bool
+        :param _EnableGeometry: 是否开启单几何生成选项，开启后会生成不带纹理的3D模型（白模）； 开启时，生成模型文件不支持OBJ格式，默认生成模型文件为GLB格式。
+        :type EnableGeometry: bool
         """
         self._Prompt = None
         self._ImageBase64 = None
         self._ImageUrl = None
         self._ResultFormat = None
         self._EnablePBR = None
+        self._EnableGeometry = None
 
     @property
     def Prompt(self):
         r"""文生3D，3D内容的描述，中文正向提示词。
 最多支持200个 utf-8 字符。
-文生3D, image、image_url和 prompt必填其一，且prompt和image/image_url不能同时存在。
+文生3D, ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :rtype: str
         """
         return self._Prompt
@@ -631,7 +634,7 @@ ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不
     @property
     def ImageBase64(self):
         r"""输入图 Base64 数据。
-大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过6m）
+大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过5m）
 格式：jpg，png，jpeg，webp。
 ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :rtype: str
@@ -645,9 +648,9 @@ ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl
     @property
     def ImageUrl(self):
         r"""输入图Url。
-大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过6m）
+大小：单边分辨率要求不小于128，不大于5000。大小不超过8m（base64编码后会大30%左右，建议实际输入图片不超过5m）
 格式：jpg，png，jpeg，webp。
-ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
+ImageBase64、ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不能同时存在。
         :rtype: str
         """
         return self._ImageUrl
@@ -680,6 +683,17 @@ ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不
     def EnablePBR(self, EnablePBR):
         self._EnablePBR = EnablePBR
 
+    @property
+    def EnableGeometry(self):
+        r"""是否开启单几何生成选项，开启后会生成不带纹理的3D模型（白模）； 开启时，生成模型文件不支持OBJ格式，默认生成模型文件为GLB格式。
+        :rtype: bool
+        """
+        return self._EnableGeometry
+
+    @EnableGeometry.setter
+    def EnableGeometry(self, EnableGeometry):
+        self._EnableGeometry = EnableGeometry
+
 
     def _deserialize(self, params):
         self._Prompt = params.get("Prompt")
@@ -687,6 +701,7 @@ ImageBase64/ImageUrl和 Prompt必填其一，且Prompt和ImageBase64/ImageUrl不
         self._ImageUrl = params.get("ImageUrl")
         self._ResultFormat = params.get("ResultFormat")
         self._EnablePBR = params.get("EnablePBR")
+        self._EnableGeometry = params.get("EnableGeometry")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
